summaryrefslogtreecommitdiffstats
path: root/chrome/browser/plugins/plugin_prefs_factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/plugins/plugin_prefs_factory.h')
-rw-r--r--chrome/browser/plugins/plugin_prefs_factory.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/chrome/browser/plugins/plugin_prefs_factory.h b/chrome/browser/plugins/plugin_prefs_factory.h
index 9087935..4e2137b 100644
--- a/chrome/browser/plugins/plugin_prefs_factory.h
+++ b/chrome/browser/plugins/plugin_prefs_factory.h
@@ -11,9 +11,9 @@
class PluginPrefs;
class Profile;
-class ProfileKeyedService;
+class BrowserContextKeyedService;
-class PluginPrefsFactory : public RefcountedProfileKeyedServiceFactory {
+class PluginPrefsFactory : public RefcountedBrowserContextKeyedServiceFactory {
public:
static scoped_refptr<PluginPrefs> GetPrefsForProfile(Profile* profile);
@@ -24,23 +24,23 @@ class PluginPrefsFactory : public RefcountedProfileKeyedServiceFactory {
friend struct DefaultSingletonTraits<PluginPrefsFactory>;
// Helper method for PluginPrefs::GetForTestingProfile.
- static scoped_refptr<RefcountedProfileKeyedService> CreateForTestingProfile(
- content::BrowserContext* profile);
+ static scoped_refptr<RefcountedBrowserContextKeyedService>
+ CreateForTestingProfile(content::BrowserContext* profile);
PluginPrefsFactory();
virtual ~PluginPrefsFactory();
- // RefcountedProfileKeyedServiceFactory methods:
- virtual scoped_refptr<RefcountedProfileKeyedService> BuildServiceInstanceFor(
- content::BrowserContext* context) const OVERRIDE;
+ // RefcountedBrowserContextKeyedServiceFactory methods:
+ virtual scoped_refptr<RefcountedBrowserContextKeyedService>
+ BuildServiceInstanceFor(content::BrowserContext* context) const OVERRIDE;
- // ProfileKeyedServiceFactory methods:
+ // BrowserContextKeyedServiceFactory methods:
virtual void RegisterUserPrefs(
user_prefs::PrefRegistrySyncable* registry) OVERRIDE;
virtual content::BrowserContext* GetBrowserContextToUse(
content::BrowserContext* context) const OVERRIDE;
virtual bool ServiceIsNULLWhileTesting() const OVERRIDE;
- virtual bool ServiceIsCreatedWithProfile() const OVERRIDE;
+ virtual bool ServiceIsCreatedWithBrowserContext() const OVERRIDE;
};
#endif // CHROME_BROWSER_PLUGINS_PLUGIN_PREFS_FACTORY_H_